"use strict";
var ts = require('typescript');
var rollup_pluginutils_1 = require('rollup-pluginutils');
var fs_1 = require('fs');
var object_assign_1 = require('object-assign');
var resolveHost = {
    fileExists: function (filePath) {
        try {
            return fs_1.statSync(filePath).isFile();
        }
        catch (err) {
            return false;
        }
    }
};
function goodErrors(diagnostic) {
    return diagnostic.code !== 1204;
}
function typescript(options) {
    options = object_assign_1.default({}, options || {});
    var filter = rollup_pluginutils_1.createFilter(options.include || ['*.ts+(|x)', '**/*.ts+(|x)'], options.exclude);
    delete options.include;
    delete options.exclude;
    options = object_assign_1.default({
        target: 1,
        module: 5,
        sourceMap: true
    }, options);
    return {
        resolveId: function (importee, importer) {
            if (!importer)
                return null;
            var result = ts.nodeModuleNameResolver(importee, importer, resolveHost);
            if (result.resolvedModule && result.resolvedModule.resolvedFileName) {
                return result.resolvedModule.resolvedFileName;
            }
            return null;
        },
        transform: function (code, id) {
            if (!filter(id))
                return null;
            var transformed = ts.transpileModule(code, {
                reportDiagnostics: true,
                compilerOptions: options
            });
            var diagnostics = transformed.diagnostics.filter(goodErrors);
            var fatalError = false;
            diagnostics.forEach(function (diagnostic) {
                var message = ts.flattenDiagnosticMessageText(diagnostic.messageText, '\n');
                if (diagnostic.file) {
                    var _a = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start), line = _a.line, character = _a.character;
                    console.error(diagnostic.file.fileName + "(" + (line + 1) + "," + (character + 1) + "): error ES" + diagnostic.code + ": " + message);
                }
                else {
                    console.error("Error: " + message);
                }
                if (diagnostic.category === ts.DiagnosticCategory.Error) {
                    fatalError = true;
                }
            });
            if (fatalError) {
                throw new Error("There were TypeScript errors transpiling \"" + id + "\"");
            }
            return {
                code: transformed.outputText,
                map: JSON.parse(transformed.sourceMapText)
            };
        }
    };
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = typescript;
